import components from './components'

function normalize (item) {
  return item ? String(item).replace(/\s+/g, ' ').trim() : null
}

function normalizePhone (item) {
  let phone = String(item).replace(/\s|\+|\/|,|-|'/g, '').replace(/\(0\)/, '').replace(/^0+/, '')
  if (phone.match(/[^\d*]/)) {
    return `FEHLER (nicht-numerische Zeichen): ${phone}`
  }
  if (phone.length === 0) {
    return null
  } else if (phone.length === 9) {
    // Assume swiss number
    phone = `+41${phone}`
  } else if (phone.length === 11) {
    phone = `+${phone}`
  } else {
    return `FEHLER (falsche Länge): ${phone}`
  }

  const len = phone.length
  return phone
}

const state = {
  players: [],
  filtered: [],
  categories: [],
  filters: {}
}

const reMobile = /^\+417/

/** Class representing a player */
class Player {
  /**
   * Create a player
   * A player data item in the Swisstennis PlayerList.xlsx file has the following columns
   * Konkurrenz | Anmeldedatum | Lizenznummer | Klub | Klub Name | Name | Vorname | Geburtsdatum | Adresse | c/o | PLZ | Ort |
   * Land | Tel P | Tel G | Mobile | Email | Klassierung | Klass. Wert | Gesetzte | Kommentar | Einschränkungen | Kommentar |
   * Lizenz Nr.Doppelpartner | Name Doppelpartner | Vorname Doppelpartner | Geburtsdatum Doppelpartner | Klassierung Doppelpartner |
   * Klass. Wert Doppelpartner | bestätigt | On-line Anmeldung | bezahlt
   */
  constructor (data) {
    this.Konkurrenz = normalize(data[0])
    this.Lizenz = normalize(data[2])
    this.geschlecht = null
    if (this.Konkurrenz) {
      if (this.Konkurrenz[0] === 'M') {
        this.geschlecht = 'm'
      } else if (this.Konkurrenz[0] === 'W') {
        this.geschlecht = 'w'
      }
    }
    this.Name = normalize(data[5])
    this.Vorname = normalize(data[6])
    this.Geburtsdatum = data[7]
    this.TelP = normalizePhone(data[13])
    this.TelG = normalizePhone(data[14])
    this.Mobile = normalizePhone(data[15])
    this.Email = normalize(data[16])
    this.Klassierung = normalize(data[17])
    this.LizenzDP = normalize(data[23])
    this.NameDP = normalize(data[24])
    this.VornameDP = normalize(data[25])
    this.GeburtsdatumDP = data[26]
    this.KlassierungDP = normalize(data[27])
    this.Bestaetigt = data[29]
    this.Bezahlt = data[31]
    this.BezahltAm = null
    this.Matches = []
    this.isDoubles = !!this.Konkurrenz.match(/DM.*|[MW]D.*/)
    this.isJunior = (this.Geburtsdatum) ? this.Geburtsdatum.getTime() >= (new Date((new Date()).getFullYear() - 19, 11, 31, 23, 59, 59, 999)).getTime() : false
    //!this.Geburtsdatum || console.log('DEBUG player:', this.Name, this.Vorname, this.Geburtsdatum, (new Date((new Date()).getFullYear() - 19, 11, 31, 23, 59, 59, 999)), this.Geburtsdatum.getTime(), (new Date((new Date()).getFullYear() - 18, 11, 31, 23, 59, 59, 999)).getTime())
    this.isJuniorDP = (this.isDoubles && this.GeburtsdatumDP) ? this.GeburtsdatumDP.getTime() >= (new Date((new Date()).getFullYear() - 19, 11, 31, 23, 59, 59, 999)).getTime() : false
    //!this.GeburtsdatumDP || console.log('DEBUG playerDP:', this.NameDP, this.VornameDP, this.GeburtsdatumDP, (new Date((new Date()).getFullYear() - 19, 11, 31, 23, 59, 59, 999)), this.GeburtsdatumDP.getTime(), (new Date((new Date()).getFullYear() - 18, 11, 31, 23, 59, 59, 999)).getTime())
    //!this.Geburtsdatum || this.Geburtsdatum.getFullYear() !== 1999 || console.log('DEBUG 99:', this.Name, this.Vorname)
    //!this.GeburtsdatumDP || this.GeburtsdatumDP.getFullYear() !== 1999 || console.log('DEBUG 99DP:', this.NameDP, this.VornameDP)
    this.name = this.isDoubles ? `${this.Name} ${this.Vorname} / ${this.NameDP} ${this.VornameDP}` : `${this.Name} ${this.Vorname}`
    if (this.Mobile && this.Mobile.match(reMobile)) {
      this.phone = this.Mobile
    } else if (this.TelP && this.TelP.match(reMobile)) {
      this.phone = this.TelP
    } else if (this.TelG && this.TelG.match(reMobile)) {
      this.phone = this.TelG
    } else if (this.Mobile && this.Mobile.match(/FEHLER/)) {
      this.phone = this.Mobile
    } else if (this.TelP && this.TelP.match(/FEHLER/)) {
      this.phone = this.TelP
    } else if (this.TelG && this.TelG.match(/FEHLER/)) {
      this.phone = this.TelG
    }
  }
}

export default { Player, components, state }
